.. _cep-index:

###############################
  Camelot Enhancement Proposals
###############################

This section contains proposals to enhance Camelot.  The functionallity
described here might not yet be implemented.  The purpose of these documents
is to discuss upcomming functions and new API's before they are implemented.

.. toctree::

   actions_new.rst
